Storage traits and implementations for refget sequences and sequence collections.
Re-exports
pub use fasta::DigestCache;pub use fasta::FastaSequenceStore;pub use fasta::FastaSequenceSummary;pub use fasta::SeqColCache;pub use fasta::SidecarCache;
Modules
- fasta
- FASTA-backed sequence store that loads sequences into memory.
Structs
- InMemory
SeqCol Store - An in-memory store of sequence collections, indexed by Level 0 digest and by per-attribute digests.
- InMemory
Sequence Store - An in-memory sequence store suitable for testing and small datasets.
- List
Item - A single item in a collection listing.
- List
Result - Result from listing collections.
- Mmap
Sequence Store - A sequence store backed by memory-mapped FASTA files.
Enums
- Store
Error - Errors from store operations.
Traits
- SeqCol
Store - Trait for storing and retrieving sequence collections.
- Sequence
Store - Trait for retrieving sequences and their metadata.
Functions
- collect_
fasta_ files - Collect FASTA files from a list of paths (files or directories).
- is_
fasta_ file - Check if a path has a FASTA file extension.
Type Aliases
- Store
Result - Result type for store operations.