FASTA-backed sequence store that loads sequences into memory.
Structs
- Cached
Digest - A single sequence’s pre-computed digests.
- Digest
Cache - Pre-computed digest cache for a FASTA file.
- Fasta
Sequence Store - A sequence store that holds all sequences in memory, loaded from indexed FASTA files.
- Fasta
Sequence Summary - Summary info for each sequence loaded from a FASTA file, useful for building SeqCol objects.
- SeqCol
Cache - Pre-computed SeqCol cache for a FASTA file.
Traits
- Sidecar
Cache - Trait for FASTA sidecar cache files (e.g.
.refget.json,.seqcol.json).