Crate refget_store

Crate refget_store 

Storage traits and implementations for refget sequences and sequence collections.

Re-exports

pub use fasta::DigestCache;
pub use fasta::FastaSequenceStore;
pub use fasta::FastaSequenceSummary;
pub use fasta::SeqColCache;
pub use fasta::SidecarCache;

Modules

fasta
FASTA-backed sequence store that loads sequences into memory.

Structs

InMemorySeqColStore
An in-memory store of sequence collections, indexed by Level 0 digest and by per-attribute digests.
InMemorySequenceStore
An in-memory sequence store suitable for testing and small datasets.
ListItem
A single item in a collection listing.
ListResult
Result from listing collections.
MmapSequenceStore
A sequence store backed by memory-mapped FASTA files.

Enums

StoreError
Errors from store operations.

Traits

SeqColStore
Trait for storing and retrieving sequence collections.
SequenceStore
Trait for retrieving sequences and their metadata.

Functions

collect_fasta_files
Collect FASTA files from a list of paths (files or directories).
is_fasta_file
Check if a path has a FASTA file extension.

Type Aliases

StoreResult
Result type for store operations.